Enum jobserver::FromEnvErrorKind
source · #[non_exhaustive]pub enum FromEnvErrorKind {
NoEnvVar,
NoJobserver,
CannotParse,
CannotOpenPath,
CannotOpenFd,
NotAPipe,
Unsupported,
}Expand description
Kind of an error returned from from_env_ext function.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoEnvVar
There is no environment variable that describes jobserver to inherit.
NoJobserver
There is no jobserver in the environment variable. Variables associated with Make can be used for passing data other than jobserver info.
CannotParse
Cannot parse jobserver environment variable value, incorrect format.
CannotOpenPath
Cannot open path or name from the jobserver environment variable value.
CannotOpenFd
Cannot open file descriptor from the jobserver environment variable value.
NotAPipe
File descriptor from the jobserver environment variable value is not a pipe.
Unsupported
Jobserver inheritance is not supported on this platform.